@@ -1,7 +1,7 @@
 ################################################################################
 # MIT License
 #
-# Copyright (c) 2020 Hajime Nakagami
+# Copyright (c) 2020-2021 Hajime Nakagami
 #
 # Permission is hereby granted, free of charge, to any person obtaining a copy
 # of this software and associated documentation files (the "Software"), to deal
@@ -21,15 +21,15 @@
 # OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 # SOFTWARE.
 ################################################################################
-
-from .tokenizer import Tokenizer
+from typing import List
+from .tokenizer import Tokenizer    # type: ignore
 
 
-def tokenize(s):
+def tokenize(s: str) -> List[str]:
     tok = Tokenizer()
     return tok.tokenize(s)
 
 
-def tokenize_n_best(s, n):
+def tokenize_n_best(s: str, n: int) -> List[List[str]]:
     tok = Tokenizer()
     return tok.tokenize_n_best(s, n)
